CREATE TABLE Mitarbeiter
(
	Nummer 			NUMBER(8) 	PRIMARY KEY,
	Vorname			VARCHAR2(64) 	NOT NULL,
	Nachname		VARCHAR2(64) 	NOT NULL,
	Geburtsdatum		DATE		NOT NULL,
	Einstelldatum		DATE		NOT NULL
);

CREATE TABLE Astronaut
(
	Nummer			NUMBER(8)	PRIMARY KEY REFERENCES Mitarbeiter(Nummer),
	realeFlugstunden	NUMBER(6)	NOT NULL CHECK(realeFlugstunden >= 0),
	virtuelleFlugstunden	NUMBER(6)	NOT NULL CHECK(virtuelleFlugstunden >= 0)
);

CREATE TABLE Verschollen
(
	Nummer			NUMBER(8)	PRIMARY KEY REFERENCES Astronaut(Nummer),
	Datum			DATE		NOT NULL
);

CREATE TABLE Qualifikation
(
	Bezeichnung		VARCHAR2(64)	PRIMARY KEY,
	Beschreibung		VARCHAR2(256)	NOT NULL
);

CREATE TABLE beherrscht
(
	Nummer			NUMBER(8)	REFERENCES Astronaut(Nummer),
	Bezeichnung		VARCHAR2(64)	REFERENCES Qualifikation(Bezeichnung),
	Bewertung		NUMBER(2)	NOT NULL CHECK(Bewertung BETWEEN 1 AND 10),
	PRIMARY KEY(Nummer, Bezeichnung)
);

CREATE TABLE Raumfahrzeug
(
	Name			VARCHAR2(64),
	Typ			VARCHAR2(64),
	Flugstunden		NUMBER(8)	NOT NULL CHECK(Flugstunden >= 0),
	PRIMARY KEY(Name, Typ)
);

CREATE TABLE benoetigt
(
	Name			VARCHAR2(64),
	Typ			VARCHAR2(64),
	Bezeichnung		VARCHAR2(64) 	REFERENCES Qualifikation(Bezeichnung),
	PRIMARY KEY(Name, Typ, Bezeichnung),
	FOREIGN KEY(Name, Typ) REFERENCES Raumfahrzeug(Name, Typ)
);

CREATE TABLE Technologie
(
	Nummer			NUMBER(8)	PRIMARY KEY,
	Beschreibung		VARCHAR2(256)	NOT NULL
);

CREATE TABLE nutzt
(
	Name			VARCHAR2(64),
	Typ			VARCHAR2(64),
	Nummer			NUMBER(8)	REFERENCES Technologie(Nummer),
	PRIMARY KEY(Name, Typ, Nummer),
	FOREIGN KEY(Name, Typ) REFERENCES Raumfahrzeug(Name, Typ)
);

CREATE TABLE Himmelskoerper
(
	Name			VARCHAR2(64)	PRIMARY KEY,
	Typ			VARCHAR2(64)	NOT NULL,
	Entfernung		NUMBER(16)	NOT NULL CHECK(Entfernung >= 0),
	Durchmesser		NUMBER(8)	NOT NULL CHECK(Durchmesser > 0)
);

CREATE TABLE Raumstation
(
	Name			VARCHAR2(64),
	Typ			VARCHAR2(64),
	HimmelskoerperName	VARCHAR2(64)	NULL REFERENCES Himmelskoerper(Name),
	seit			DATE		NULL,
	PRIMARY KEY(Name, Typ),
	FOREIGN KEY(Name, Typ) REFERENCES Raumfahrzeug(Name, Typ)
);

CREATE TABLE Raumfaehre
(
	Name			VARCHAR2(64),
	Typ			VARCHAR2(64),
	Flugstrecke		NUMBER(16)	NOT NULL CHECK(Flugstrecke >= 0),
	Fluege			NUMBER(8)	NOT NULL CHECK(Fluege >= 0),
	PRIMARY KEY(Name, Typ),
	FOREIGN KEY(Name, Typ) REFERENCES Raumfahrzeug(Name, Typ)
);

CREATE TABLE Team
(
	Nummer			NUMBER(8)	PRIMARY KEY,
	Name			VARCHAR2(64)	NOT NULL
);

CREATE TABLE mitglied
(
	MitarbeiterNummer	NUMBER(8)	REFERENCES Mitarbeiter(Nummer),
	TeamNummer		NUMBER(8)	REFERENCES Team(Nummer),
	seit			DATE		NOT NULL,
	PRIMARY KEY(MitarbeiterNummer, TeamNummer)
);

CREATE TABLE Mission
(
	Beginn			DATE,
	HName			VARCHAR2(64)	REFERENCES Himmelskoerper(Name),
	RName			VARCHAR2(64),
	RTyp			VARCHAR2(64),
	TNummer			NUMBER(8)	NULL REFERENCES Team(Nummer),
	Dauer			NUMBER(8)	NOT NULL CHECK(Dauer >= 0),
	PRIMARY KEY(Beginn, HName, RName, RTyp),
	FOREIGN KEY(RName, RTyp) REFERENCES Raumfaehre(Name, Typ)
);
